Sheet class

A wrapper for the parameters that pertain to an Animated/Container.

If not provided an initializing color nor decoration, this field defaults to Colors.black so that a Foil.sheet has pixels to which it can mask its gradient.

Note that if provided a decoration, but that Decoration has no color, and no initializing color value was provided either, this Sheet may potentially result in a layer that has no pixels to which a Foil may be masked.

See also:

  • new Container, whose properties this Sheet mimics
Mixed-in types

Constructors

Sheet({Color? color, double? width, double? height, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, AlignmentGeometry? alignment, Decoration? decoration, Decoration? foregroundDecoration, Clip clipBehavior = Clip.none, BoxConstraints? constraints, Matrix4? transform, AlignmentGeometry? transformAlignment})
A wrapper for the parameters that pertain to an Animated/Container.
const

Properties

alignment → AlignmentGeometry?
See Container.alignment.
final
clipBehavior → Clip
Default is Clip.none which allows visual overflow.
Clipping has performance implications. See also: Container.clipBehavior.
final
color → Color?
Background color. If not provided an initializing color nor decoration, this field defaults to Colors.black so that a Foil.sheet has pixels to which it can mask its gradient.
final
constraints → BoxConstraints?
Constrain dimensions.
final
decoration → Decoration?
A Decoration, likely a BoxDecoration or ShapeDecoration, to apply as a background. This can define color, shape, border and more.
final
foregroundDecoration → Decoration?
A Decoration, likely a BoxDecoration, to apply as a decoration in the front layer of presentation.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
Provide intrinsic dimensions.
final
margin → EdgeInsetsGeometry?
EdgeInsets to apply on the outside edge, condensing the space available to the container and content within it.
final
padding → EdgeInsetsGeometry?
EdgeInsets to apply on the inner edge, padding the content within.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform → Matrix4?
A Matrix4 is a complex array of 0s or other values that describe how to translate, rotate, offset, shift perspective, or otherwise transform the widget.
final
transformAlignment → AlignmentGeometry?
If providing a transform, optionally specify how to align it.
final
width → double?
Provide intrinsic dimensions.
final

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited