TranslateGradient class
This class's transform method considers TextDirection and
will consider positive values as translation to the right if ltr
and translate left for positive values if rtl.
The default TransformGradient for Foil.
- Inheritance
-
- Object
- GradientTransform
- TranslateGradient
- Mixed-in types
Constructors
- TranslateGradient({required double percentX, required double percentY})
-
This class's transform method considers TextDirection and
will consider positive values as translation to the right if
ltrand translate left for positive values ifrtl.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- percentX → double
-
An unbounded
doublethat represents a percentage of the Rectboundsto translate the gradient. May be positive or negative. May exceed± 1.0.final - percentY → double
-
An unbounded
doublethat represents a percentage of the Rectboundsto translate the gradient. May be positive or negative. May exceed± 1.0.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
transform(
Rect bounds, {TextDirection? textDirection}) → Matrix4? -
When a Gradient creates its Shader, it will call this method to
determine what transform to apply to the shader for the given Rect and
TextDirection.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited